==> weblog-1_30.tar.gz: weblog/language/japanese/admin.php <==
<?php
/**
 * $Id: admin.php,v 1.3 2003/10/26 08:28:42 wellwine Exp $
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place
 */
define('_AM_WEBLOG_CONFIG', $xoopsModule->name().'');
define('_AM_WEBLOG_PREFERENCES', _PREFERENCES);
define('_AM_WEBLOG_PREFERENCESDSC', 'Ūưꤷޤ');
define('_AM_WEBLOG_GO', _GO);
define('_AM_WEBLOG_CANCEL', _CANCEL);
define('_AM_WEBLOG_DELETE', _DELETE);
define('_AM_WEBLOG_TITLE', 'Title');

define('_AM_WEBLOG_DBMANAGER', 'ǡ١');
define('_AM_WEBLOG_DBMANAGERDSC', '⥸塼ΥС󥢥åפκݤ˥ǡ١ޤ');
define('_AM_WEBLOG_TABLE', 'ơ֥');
define('_AM_WEBLOG_SYNCCOMMENTS', 'ȿƱ');
define('_AM_WEBLOG_SYNCCOMMENTSDSC', '⤷ƥȥΥȿäƤȻפϡǡκƽפԤȤǤޤ<br />v1.02ΥСǤϥȿäƤʤäǤ뤳Ȥޤ');
define('_AM_WEBLOG_CHECKTABLE', 'ơ֥빽ǧ');
define('_AM_WEBLOG_CHECKTABLEDSC', 'СǤϿΥơ֥䥫बɬפʾ礬ޤ<br />Сȥơ֥ǧ뤳ȤǤޤ');
define('_AM_WEBLOG_CREATETABLE', '\'%s\'ơ֥');
define('_AM_WEBLOG_CREATETABLEDSC', '\'%s\'Ȥ̾Υơ֥򿷵˺ޤ');

define('_AM_WEBLOG_ADD', '\'%s\'बĤޤ');
define('_AM_WEBLOG_ADDDSC', '\'<b>%s</b>\'बǡ١Υơ֥ˤޤ󡣤ΥϸߤѤΥСɬפʥǤ<br />ܥ򲡤ƤΥɲäƤ<br />ǡ١ΥХååפ򤪴ᤷޤ');
define('_AM_WEBLOG_NOADD', '\'%s\'ơ֥ϽλǤ');
define('_AM_WEBLOG_NOADDDSC', '\'%s\'ơ֥ϸߤѤΥСǤȤˤʤ֤Ǥ');
define('_AM_WEBLOG_DBUPDATED', 'ǡ١򹹿ޤ');
define('_AM_WEBLOG_UNSUPPORTED', 'ݡȤƤʤꥯȤǤϹԤޤǤ');
define('_AM_WEBLOG_TABLEADDED', 'ơ֥뤬˺ޤ');
define('_AM_WEBLOG_TABLENOTADDED', 'ơ֥뤬ǤޤǤ: %s');
define('_AM_WEBLOG_COLADDED', 'ब˺ޤ');
define('_AM_WEBLOG_COLNOTADDED', 'ɲä뤳ȤǤޤǤ: %s');

define('_AM_WEBLOG_CATMANAGER', 'ƥ');
define('_AM_WEBLOG_CATMANAGERDSC', 'ƥɲ//');
define('_AM_WEBLOG_ADDCAT', 'ƥɲ');
define('_AM_WEBLOG_ADDMAINCAT', 'ᥤ󥫥ƥɲ');
define('_AM_WEBLOG_ADDSUBCAT', '֥ƥɲ');
define('_AM_WEBLOG_CAT', 'ƥ');
define('_AM_WEBLOG_IMGURL', 'URL');
define('_AM_WEBLOG_ERRORTITLE', 'ȥϤƤ');
define('_AM_WEBLOG_NEWCATADDED', 'ƥ꤬ɲäޤ');
define('_AM_WEBLOG_CATNOTADDED', 'ƥɲä뤳ȤǤޤǤ');
define('_AM_WEBLOG_CATMODED', 'ƥ꤬ޤ');
define('_AM_WEBLOG_CATNOTMODED', 'ƥ뤳ȤǤޤǤ');
define('_AM_WEBLOG_MODCAT', 'ƥν');
define('_AM_WEBLOG_PCAT', 'ƥƥ');
define('_AM_WEBLOG_CHOSECAT', '򤷤ƥ');
define('_AM_WEBLOG_DELCONFIRM', '\'%s\' ƥȤΥ֥ƥƤǤ<br />Υƥ°뤹٤ƤΥȥޤ');
define('_AM_WEBLOG_CATDELETED', 'ƥ꤬ޤ');

define('_AM_WEBLOG_PRIVMANAGER', '´');
define('_AM_WEBLOG_PRIVMANAGERDSC', 'ƤǤꤷޤ');
define('_AM_WEBLOG_ADDPRIV', _ADD);
define('_AM_WEBLOG_DELETEPRIV', _DELETE);
define('_AM_WEBLOG_NONPRIV', 'Ƹ¤ʤ');
define('_AM_WEBLOG_PRIV', 'Ƹ¤');
?>

==> weblog-1_42.tar.gz: weblog/language/japanese/admin.php <==
<?php
/**
 * $Id: admin.php,v 1.8 2005/08/14 06:15:44 tohokuaiki Exp $
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place
 */
 
if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'WEBLOG_AM_LOADED' ) ) {
global $xoopsModule ;
define( 'WEBLOG_AM_LOADED' , 1 ) ;

define('_AM_WEBLOG_CONFIG', $xoopsModule->name().'');
define('_AM_WEBLOG_PREFERENCES', _PREFERENCES);
define('_AM_WEBLOG_PREFERENCESDSC', 'Ūưꤷޤ');
define('_AM_WEBLOG_GO', _GO);
define('_AM_WEBLOG_CANCEL', _CANCEL);
define('_AM_WEBLOG_DELETE', _DELETE);
define('_AM_WEBLOG_MODIFY', 'ѹ');
define('_AM_WEBLOG_TITLE', 'Title');

define('_AM_WEBLOG_DBMANAGER', 'ǡ١');
define('_AM_WEBLOG_DBMANAGERDSC', '⥸塼ΥС󥢥åפκݤ˥ǡ١ޤ');
define('_AM_WEBLOG_TABLE', 'ơ֥');
define('_AM_WEBLOG_SYNCCOMMENTS', 'ȿƱ');
define('_AM_WEBLOG_SYNCCOMMENTSDSC', '⤷ƥȥΥȿäƤȻפϡǡκƽפԤȤǤޤ<br />v1.02ΥСǤϥȿäƤʤäǤ뤳Ȥޤ');
define('_AM_WEBLOG_CHECKTABLE', 'ơ֥빽ǧ');
define('_AM_WEBLOG_CHECKTABLEDSC', 'СǤϿΥơ֥䥫बɬפʾ礬ޤ<br />Сȥơ֥ǧ뤳ȤǤޤ');
define('_AM_WEBLOG_CREATETABLE', '\'%s\'ơ֥');
define('_AM_WEBLOG_CREATETABLEDSC', '\'%s\'Ȥ̾Υơ֥򿷵˺ޤ');

define('_AM_WEBLOG_ADD', '\'%s\'बĤޤ');
define('_AM_WEBLOG_ADDDSC', '\'<b>%s</b>\'बǡ١Υơ֥ˤޤ󡣤ΥϸߤѤΥСɬפʥǤ<br />ܥ򲡤ƤΥɲäƤ<br />ǡ١ΥХååפ򤪴ᤷޤ');
define('_AM_WEBLOG_NOADD', '\'%s\'ơ֥ϽλǤ');
define('_AM_WEBLOG_NOADDDSC', '\'%s\'ơ֥ϸߤѤΥСǤȤˤʤ֤Ǥ');
define('_AM_WEBLOG_DBUPDATED', 'ǡ١򹹿ޤ');
define('_AM_WEBLOG_UNSUPPORTED', 'ݡȤƤʤꥯȤǤϹԤޤǤ');
define('_AM_WEBLOG_TABLEADDED', 'ơ֥뤬˺ޤ');
define('_AM_WEBLOG_TABLENOTADDED', 'ơ֥뤬ǤޤǤ: %s');
define('_AM_WEBLOG_COLADDED', 'ब˺ޤ');
define('_AM_WEBLOG_COLNOTADDED', 'ɲä뤳ȤǤޤǤ: %s');

define('_AM_WEBLOG_CATMANAGER', 'ƥ');
define('_AM_WEBLOG_CATMANAGERDSC', 'ƥɲ//');
define('_AM_WEBLOG_ADDCAT', 'ƥɲ');
define('_AM_WEBLOG_ADDMAINCAT', 'ᥤ󥫥ƥɲ');
define('_AM_WEBLOG_ADDSUBCAT', '֥ƥɲ');
define('_AM_WEBLOG_CAT', 'ƥ');
define('_AM_WEBLOG_IMGURL', 'URL');
define('_AM_WEBLOG_ERRORTITLE', 'ȥϤƤ');
define('_AM_WEBLOG_NEWCATADDED', 'ƥ꤬ɲäޤ');
define('_AM_WEBLOG_CATNOTADDED', 'ƥɲä뤳ȤǤޤǤ');
define('_AM_WEBLOG_CATMODED', 'ƥ꤬ޤ');
define('_AM_WEBLOG_CATNOTMODED', 'ƥ뤳ȤǤޤǤ');
define('_AM_WEBLOG_MODCAT', 'ƥν');
define('_AM_WEBLOG_PCAT', 'ƥƥ');
define('_AM_WEBLOG_CHOSECAT', '򤷤ƥ');
define('_AM_WEBLOG_DELCONFIRM', '\'%s\' ƥȤΥ֥ƥƤǤ<br />Υƥ°뤹٤ƤΥȥޤ');
define('_AM_WEBLOG_CATDELETED', 'ƥ꤬ޤ');
define('_AM_WEBLOG_CAT_GPERM', 'ΥƥƤĤ륰롼');
define('_AM_WEBLOG_CAT_OPERATE', '');
define('_AM_WEBLOG_CAT_SETALL', 'ƤΥ롼ΥƥƸ¤٤ꤹ');


define('_AM_WEBLOG_MYBLOCKSADMIN', '֥å');
define('_AM_WEBLOG_MYBLOCKSADMINDSC', '֥åȡ롼פȤԤޤ');
define('_AM_WEBLOG_TEMPLATE_MANEGER', 'ƥץ졼');
define('_AM_WEBLOG_TEMPLATE_MANEGERDSC', 'ƥץ졼ȡޥ͡ؤΥ硼ȥå');

define('_AM_WEBLOG_PRIVMANAGER_WEBLOG', '´(weBLogƥ)');
define('_AM_WEBLOG_PRIVMANAGER_WEBLOG_DSC', 'ƤǤꤷޤ');
define('_AM_WEBLOG_PRIVMANAGER_WEBLOG_CAUTION', 'ǤϡǸ´ƥ"weBLog simple system"ͭǤ');
define('_AM_WEBLOG_PRIVMANAGER_XOOPS', '´(XOOPSɸॷƥ)');
define('_AM_WEBLOG_PRIVMANAGER_XOOPS_DSC', 'ơǤꤷޤ');
define('_AM_WEBLOG_PRIVMANAGER_XOOPS_CAUTION', 'ǤϡǸ´ƥ"XOOPS standard system"ͭǤ');
define('_AM_WEBLOG_ADDPRIV', _ADD);
define('_AM_WEBLOG_DELETEPRIV', _DELETE);
define('_AM_WEBLOG_NONPRIV', 'Ƹ¤ʤ');
define('_AM_WEBLOG_PRIV', 'Ƹ¤');

define('_AM_WEBLOG_GROUPPERM_GLOBAL' , '롼θ´' );
define('_AM_WEBLOG_GROUPPERM_GLOBALDESC' , '롼θ´Ԥޤ<br />ȤơԽθ¤ͿƤⵡǽޤ' );
define('_AM_WEBLOG_GPERMUPDATED' , '롼θ¤򥢥åץǡȤޤ' );
define('_AM_WEBLOG_PRIV_EDIT' , 'ơԽ') ;
define('_AM_WEBLOG_PRIV_READINDEX' , '(index/rss/rdf)') ;
define('_AM_WEBLOG_PRIV_READDETAIL' , 'ܺٱ(details.php)') ;


}
?>
